@@ -3,7 +3,7 @@
 #
 #    Intersections of line segments
 #    
-#    $Revision: 1.3 $   $Date: 2007/03/16 13:32:41 $
+#    $Revision: 1.6 $   $Date: 2008/02/04 11:26:54 $
 #
 #
 crossing.psp <- function(A,B) {
@@ -54,6 +54,7 @@ crossing.psp <- function(A,B) {
 }
 
 test.crossing.psp <- function(A,B) {
+  # return logical matrix specifying whether A[i] and B[j] cross
   verifyclass(A, "psp")
   verifyclass(B, "psp")
   eps <- .Machine$double.eps
@@ -84,11 +85,51 @@ test.crossing.psp <- function(A,B) {
             dxb=as.double(dxb),
             dyb=as.double(dyb), 
             eps=as.double(eps),
-            ok=as.integer(integer(1)),
-     PACKAGE="spatstat")$ok
-  return(out != 0)
+            ok=as.integer(integer(na * nb)),
+     PACKAGE="spatstat")
+
+  hit <- (matrix(out$ok, na, nb) != 0)
+  return(hit)
 }
 
+anycrossing.psp <- function(A,B) {
+  # equivalent to: any(test.crossing.psp(A,B))
+  # Test whether two psp objects have at least one crossing point
+  verifyclass(A, "psp")
+  verifyclass(B, "psp")
+  eps <- .Machine$double.eps
+
+  na <- A$n
+  eA <- A$ends
+  x0a <- eA$x0
+  y0a <- eA$y0
+  dxa <- eA$x1 - eA$x0
+  dya <- eA$y1 - eA$y0
+
+  nb <- B$n
+  eB <- B$ends
+  x0b <- eB$x0
+  y0b <- eB$y0
+  dxb <- eB$x1 - eB$x0
+  dyb <- eB$y1 - eB$y0
+  
+  out <- .C("xysiANY",
+            na=as.integer(na),
+            x0a=as.double(x0a),
+            y0a=as.double(y0a),
+            dxa=as.double(dxa),
+            dya=as.double(dya), 
+            nb=as.integer(nb),
+            x0b=as.double(x0b),
+            y0b=as.double(y0b),
+            dxb=as.double(dxb),
+            dyb=as.double(dyb), 
+            eps=as.double(eps),
+            ok=as.integer(integer(1)),
+     PACKAGE="spatstat")
+  hit <- (out$ok != 0)
+  return(hit)
+}
 
 selfcrossing.psp <- function(A) {
   verifyclass(A, "psp")
@@ -125,3 +166,28 @@ selfcrossing.psp <- function(A) {
 }
 
 
+test.selfcrossing.psp <- function(A) {
+  verifyclass(A, "psp")
+  eps <- .Machine$double.eps
+
+  n <- A$n
+  eA <- A$ends
+  x0 <- eA$x0
+  y0 <- eA$y0
+  dx <- eA$x1 - eA$x0
+  dy <- eA$y1 - eA$y0
+
+  out <- .C("xysxi",
+            na=as.integer(n),
+            x0=as.double(x0),
+            y0=as.double(y0),
+            dx=as.double(dx),
+            dy=as.double(dy), 
+            eps=as.double(eps),
+            ok=as.integer(integer(n*n)),
+     PACKAGE="spatstat")
+  hit <- (matrix(out$ok, n, n) != 0)
+  return(hit)
+}
+
+
