@@ -1,28 +1,28 @@
+C Output from Public domain Ratfor, version 1.0
       subroutine arand(ix,iy,iz,rand)
       implicit double precision(a-h,o-z)
       ix = 171 * (ix - 177*(ix/177)) - 2 * (ix/177)
       iy = 172 * (iy - 176*(iy/176)) - 35 * (iy/176)
       iz = 170 * (iz - 178*(iz/178)) - 63 * (iz/178)
-      if(.not.(ix .lt. 0))goto 23000
+      if(ix .lt. 0)then
       ix = ix + 30269
-23000 continue
-      if(.not.(iy .lt. 0))goto 23002
+      endif
+      if(iy .lt. 0)then
       iy = iy + 30307
-23002 continue
-      if(.not.(iz .lt. 0))goto 23004
+      endif
+      if(iz .lt. 0)then
       iz = iz + 30323
-23004 continue
+      endif
       term = ix/30269.d0 + iy/30307.d0 + iz/30323.d0
       iterm = term
-      if(.not.(iterm .gt. term))goto 23006
+      if(iterm .gt. term)then
       iterm = iterm - 1
-23006 continue
+      endif
       rand = term - iterm
-      if(.not.(rand .lt. 1.d0))goto 23008
+      if(rand .lt. 1.d0)then
       continue
-      goto 23009
-23008 continue
+      else
       rand = 0.999999d0
-23009 continue
+      endif
       return
       end
